@@ -10,6 +10,10 @@ from scipy.special import poch,factorial2,binom,factorial,gamma,hyp2f1
 from collections import defaultdict
 import warnings
 
+def _fact2(n):
+    """Replacement for scipy's factorial2 with desired behavior for n==-1"""
+    return 1 if n==-1 else factorial2(n)
+        
 def get_df_term_latex(k1,k2,k3,k4,k5,k6,nu1,nu2,nu3,nu4,l1,l2,indexIn,indexOut):
     r"""
     Get the latex expression for the disturbing function coefficient
@@ -119,7 +123,7 @@ def _delta(*args):
     Return 0 if all arguments are 0, otherwise return 1.
     """
     intarr  = np.array([args],dtype=np.int64)
-    if np.alltrue(intarr == 0):
+    if np.all(intarr == 0):
         return 0
     else:
         return 1
@@ -207,6 +211,7 @@ def k_nu_depend_on_eccentricities(k,nu):
     _,_,nu3,nu4 = nu
     arr=np.array([k3,k4,nu3,nu4])
     return np.any(arr!=0)
+
 def list_resonance_terms(p,q,min_order=None,max_order=None,eccentricities=True,inclinations=True):
     """
     Generate the list of disturbing function terms for a
@@ -237,10 +242,14 @@ def list_resonance_terms(p,q,min_order=None,max_order=None,eccentricities=True,i
         Each entry in the list is of the form
         (k_vec, nu_vec) (see PoincareHamiltonian.add_cosine_term in poincare.py)
     """
+
     if not min_order:
         min_order = q
     if not max_order:
         max_order = q
+    if q==0:
+        sec_terms = list_secular_terms(min_order,max_order,eccentricities=eccentricities,inclinations=inclinations)
+        return [ ((p,-p,*k[2:]),nu) for k,nu in sec_terms ]
     args_dict = df_arguments_dictionary(max_order)
     args = []
     for N in range(min_order,max_order+1):
@@ -259,7 +268,7 @@ def list_resonance_terms(p,q,min_order=None,max_order=None,eccentricities=True,i
                             continue
                         args.append((k_vec,nu_vec))
     return args
-
+        
 def list_secular_terms(min_order,max_order,eccentricities=True,inclinations=True):
     """
     Generate the list of secular disturbing function terms 
@@ -306,7 +315,7 @@ def list_secular_terms(min_order,max_order,eccentricities=True,inclinations=True
 
 def laplace_b(s,j,n,alpha):
     r"""
-    Calculates :math:`n`th derivative with respect to :math:`\alpha` of Laplace coefficient :math:`b_s^j(\alpha)`.
+    Calculates :math:`n`-th derivative with respect to :math:`\alpha` of Laplace coefficient :math:`b_s^j(\alpha)`.
     Uses recursion and scipy special functions. 
 
     Arguments
@@ -655,15 +664,15 @@ def KaulaF(n,q,p,j):
     float
     """
     if q==0 and 2 * p == n:
-        return (-1)**(j+n) * binom(n,j) * binom(n+j,j) * factorial2(n-1) / factorial2(n)
+        return (-1)**(j+n) * binom(n,j) * binom(n+j,j) * _fact2(n-1) / _fact2(n)
     if n - 2*p - q < 0: 
         if n-q<0: return 0
         return (-1)**(n-q) * factorial(n+q) * KaulaF(n,-q,n-p,j) / factorial(n-q)
-    numerator =  (-1)**j * factorial2(2*n-2*p-1)     
+    numerator =  (-1)**j * _fact2(2*n-2*p-1)     
     numerator *= binom(n/2+p+q/2,j) 
     numerator *= threeFtwo([-j,-2*p,-n-q],[1+n-2*p-q,-(n/2)-p-q/2]) 
     if p<0: return 0.
-    denom =  factorial(n -2 * p - q) * factorial2(2 * p)
+    denom =  factorial(n -2 * p - q) * _fact2(2 * p)
     return numerator / denom 
 
 def KK(i,n,m):
@@ -683,7 +692,7 @@ def FX(h,k,i,p,u,v1,v2,v3,v4,z1,z2,z3,z4):
     nlim1 = int(np.ceil(max(h,(h + abs(k)) / 2)))
     nlim2 = i
     hplusk_mod2 = (h+k) % 2
-    delta = 1 - np.alltrue(np.array([h,k,v1-v2,v4-v3]) == 0)
+    delta = 1 - np.all(np.array([h,k,v1-v2,v4-v3]) == 0)
     inc_total= 0
     for n in getrange(nlim1,nlim2,1):
         mlim1 = max(n-i,p-n+h,p-k-n+hplusk_mod2)
@@ -692,6 +701,8 @@ def FX(h,k,i,p,u,v1,v2,v3,v4,z1,z2,z3,z4):
             term = (-1)**abs(k+m+n-p) * KK(i,n,m)
             term *= KaulaF(n,-k-m+p,(-h + m + n - p)//2,z1)
             term *= KaulaF(n, k+m-p,(-h - m + n + p)//2,z2)
+            KF1 = KaulaF(n,-k-m+p,(-h + m + n - p)//2,z1)
+            KF2 = KaulaF(n, k+m-p,(-h - m + n + p)//2,z2)
             inc_total += term
     
     ecc_total = 0
@@ -700,7 +711,7 @@ def FX(h,k,i,p,u,v1,v2,v3,v4,z1,z2,z3,z4):
         term *= HansenCoefficient_term(i+t,v1,v2,z3)
         term *= HansenCoefficient_term(-1-i-t,v3,v4,z4)
         ecc_total += term
-        
+
     return (1 + delta) * inc_total * ecc_total
 
     
@@ -776,14 +787,14 @@ def df_coefficient_Ctilde(k1,k2,k3,k4,k5,k6,nu1,nu2,nu3,nu4,include_indirect = T
                 )
         return dict(total)
     kvec = np.array([k1,k2,k3,k4,k5,k6])
-    if np.alltrue(kvec==0):
+    if np.all(kvec==0):
         for i in getrange(0,nu1+nu2,1):
             for p in getrange(i%2,i,2):
                 for u in getrange(0,2*nu3+2*nu4):
                     cf = FX(0,0,i,p,u,0,0,0,0,nu1,nu2,nu3,nu4) * (1 + (p != 0))
                     if not np.isclose(cf,0):
                         total[(i+u,(i+1/2,abs(p),u))]+=cf
-    elif np.alltrue(kvec[2:]==0):
+    elif np.all(kvec[2:]==0):
         j = abs(k1)
         for i in getrange(0,nu1+nu2,1):
             for p in getrange(i%2,i,2):
@@ -914,7 +925,7 @@ def df_coefficient_C(k1,k2,k3,k4,k5,k6,nu1,nu2,nu3,nu4,l1=0,l2=0,include_indirec
     """
     Chat = defaultdict(float)
     msg = "Integer arguments nu_i and l_i must be non-negative."
-    assert np.alltrue(np.array([nu1,nu2,nu3,nu4,l1,l2])>=0), msg
+    assert np.all(np.array([nu1,nu2,nu3,nu4,l1,l2])>=0), msg
     for n3 in range(nu3+1):
         for n4 in range(nu4+1):
             term_dict = df_coefficient_Ctilde(k1,k2,k3,k4,k5,k6,nu1,nu2,n3,n4,include_indirect_terms)
@@ -1229,7 +1240,7 @@ def _consolidate_dictionary_terms(d):
         elif k[3] !=0:
            k *= np.sign(k[3]) 
         else: 
-            assert np.alltrue(k==0) and not np.alltrue(np.array(z)==0), "Suspected bad k,z={},{} pair in term dictionary!".format(k,z)
+            assert np.all(k==0) and not np.all(np.array(z)==0), "Suspected bad k,z={},{} pair in term dictionary!".format(k,z)
         dnew[(tuple(k),z)] += val
     return dict(dnew)
 
