@@ -17,7 +17,7 @@ def _my_elliptic_e(*args):
     else:
         return scipy.special.ellipeinc(*args)
 
-_lambdify_kwargs = {'modules':['numpy', {
+_default_lambdify_kwargs = {'modules':['numpy', {
     'elliptic_k': scipy.special.ellipk,
     'elliptic_f': scipy.special.ellipkinc,
     'elliptic_e': _my_elliptic_e
@@ -154,6 +154,7 @@ class Hamiltonian(object):
         self.state = state
         self._full_qp_vars = full_qp_vars
         self._needs_update = True
+        self._lambdify_kwargs = _default_lambdify_kwargs
         
     @property
     def t(self):
@@ -217,7 +218,7 @@ class Hamiltonian(object):
         return self.state.values
     @values.setter
     def values(self,vals):
-        self.state.values = values
+        self.state.values = vals
 
     @property
     def full_values(self):
@@ -449,17 +450,8 @@ class Hamiltonian(object):
         self._needs_update=False # reset flag up top to avoid infinite recursion
         self._N_H = self._H # reset to Hamiltonian with all parameters unset
         # 
-        # Update raw numerical constants first then update functions
-        # Less hacky way to do this?
-        function_keyval_pairs = []
-        for key, val in self._H_params.items(): 
-            if isinstance(val,float):
-                self._N_H = self._N_H.subs(key, val)
-            else:
-                function_keyval_pairs.append((key,val)) 
-        for keyval in function_keyval_pairs:
-            self._N_H = self._N_H.subs(keyval[0],keyval[1])
-
+        # Change subs to xreplace here, Dec 7 2022
+        self._N_H = self._N_H.xreplace(self._H_params)
         qp_vars = self.qp_vars
         flow = []
         Nflow = []
@@ -475,9 +467,9 @@ class Hamiltonian(object):
         self._jacobian = Matrix(N_dim,N_dim, lambda i,j: diff(flow[i],qp_vars[j]))
         self._N_jacobian = Matrix(N_dim,N_dim, lambda i,j: diff(Nflow[i],qp_vars[j]))
 
-        self._H_func = lambdify(qp_vars,self._N_H,**_lambdify_kwargs)
-        self._flow_func = lambdify(qp_vars,self._N_flow,**_lambdify_kwargs)
-        self._jacobian_func = lambdify(qp_vars,self._N_jacobian,**_lambdify_kwargs)
+        self._H_func = lambdify(qp_vars,self._N_H,**self._lambdify_kwargs)
+        self._flow_func = lambdify(qp_vars,self._N_flow,**self._lambdify_kwargs)
+        self._jacobian_func = lambdify(qp_vars,self._N_jacobian,**self._lambdify_kwargs)
 
         self._integrator = ode(
                 lambda t,y: self._flow_func(*y),
