@@ -159,10 +159,16 @@ def _Dsk_integral_fixed_quad(k,y,Nquad):
     return (2/np.pi) * integrand @ weights
 
 def getOmegaMatrix(n):
-    """
-    Get the 2n x 2n skew-symmetric block matrix:
-          [0 , I_n]
-          [-I_n, 0 ]
+    r"""
+    Get the 2n x 2n skew-symmetric block matrix
+
+    .. math::
+        \begin{pmatrix}
+           0 & I_n \\
+          -I_n & 0 
+        \end{pmatrix},
+
+    where :math:`I_n` is the :math:`n \times n` identity matrix,
     that appears in Hamilton's equations.
 
     Arguments
@@ -182,6 +188,75 @@ def getOmegaMatrix(n):
          np.concatenate([-I,zeros]).T
         )
     )
+####################################################
+################ Orbit linking #####################
+####################################################
+def EulerMatrix(Omega,inc,omega):
+    """
+    The Euler 3D rotation matrix for Euler angles (Omega,inc,omega). The (3,1,3)
+    convention is followed.
+
+    Parameters
+    ----------
+    Omega : float
+        First Euler angle (ascending node)
+    inc : float
+        Second Euler angle (inclination)
+    omega : float
+        Third Euler angle (argument of periapsis)
+
+    Returns
+    -------
+    numpy.array
+        3 x 3 rotation matrix
+    """
+    R = np.eye(3)
+    s,c = np.sin(omega),np.cos(omega)
+    R = np.array([[c,-s,0],[s,c,0],[0,0,1]]) @ R
+    s,c = np.sin(inc),np.cos(inc)
+    R = np.array([[1,0,0],[0,c,-s],[0,s,c]]) @ R
+    s,c = np.sin(Omega),np.cos(Omega)
+    R = np.array([[c,-s,0],[s,c,0],[0,0,1]]) @ R
+    return R
+
+def linking_l(orbit1,orbit2):
+    """
+    Computes the linking coefficient defined by `Kholshevnikov and Vassiliev
+    (1999) <https://ui.adsabs.harvard.edu/abs/1999CeMDA..75...67K/abstract>`_
+    for a pair of Keplerian orbits.
+
+    Parameters
+    ----------
+    orbit1 : rebound.Orbit
+        First orbit
+    orbit2 : rebound.Orbit
+        Second orbit
+
+    Returns
+    -------
+    float
+        The linking coefficient, :math:`l_1`, defined by Equation (1) of
+        Kholshevnikov and Vassiliev (1999)
+    """
+    mtrx1 = EulerMatrix(orbit1.Omega,orbit1.inc,orbit1.omega)
+    mtrx2 = EulerMatrix(orbit2.Omega,orbit2.inc,orbit2.omega)
+    P1,Q1,Z1 = mtrx1.T
+    P2,Q2,Z2 = mtrx2.T
+    wvec = np.cross(Z1,Z2)
+    w = np.linalg.norm(wvec)
+    a1,e1 = orbit1.a,orbit1.e
+    a2,e2 = orbit2.a,orbit2.e
+
+    p1 = a1 * (1 - e1*e1)
+    p2 = a2 * (1 - e2*e2)
+
+    R1 = p1 * w / (w - e1 * np.dot(P1,wvec))
+    R2 = p2 * w / (w - e2 * np.dot(P2,wvec))
+    r1 = p1 * w / (w + e1 * np.dot(P1,wvec))
+    r2 = p2 * w / (w + e2 * np.dot(P2,wvec))
+    return (r2-r1)*(R2-R1)
+
+
 ######################################################
 ################ AMD Calculation #####################
 ######################################################
@@ -287,7 +362,9 @@ def compute_AMD(sim):
         The value of the systems angular momentum 
         deficit.
     """
-
+    # copy sim and move to center of mass
+    sim = sim.copy()
+    sim.move_to_com()
     pstar = sim.particles[0]
     Mstar = pstar.m
     Ltot = pstar.m * np.cross(pstar.xyz,pstar.vxyz)
@@ -330,8 +407,8 @@ def AMD_stable_Q(sim):
     for i in range(len(ps)-1):
         pIn = ps[i]
         pOut = ps[i+1]
-        orbIn = pIn.calculate_orbit(pstar)
-        orbOut = pOut.calculate_orbit(pstar)
+        orbIn = pIn.orbit(pstar)
+        orbOut = pOut.orbit(pstar)
         alpha = orbIn.a / orbOut.a
         gamma = pIn.m / pOut.m
         LmbdaOut = pOut.m * np.sqrt(orbOut.a)
@@ -378,8 +455,8 @@ def AMD_stability_coefficients(sim,overlap=False):
     for i in range(len(ps)-1):
         pIn = ps[i]
         pOut = ps[i+1]
-        orbIn = pIn.calculate_orbit(pstar)
-        orbOut = pOut.calculate_orbit(pstar)
+        orbIn = pIn.orbit(pstar)
+        orbOut = pOut.orbit(pstar)
         alpha = orbIn.a / orbOut.a
         gamma = pIn.m / pOut.m
         LmbdaOut = pOut.m * np.sqrt(orbOut.a)
@@ -395,15 +472,20 @@ def AMD_stability_coefficients(sim,overlap=False):
 ######################################################
 ######################## FMFT ########################
 ######################################################
-p2d = np.ctypeslib.ndpointer(dtype = np.float,ndim = 2,flags = 'C')
-_fmft = clibcelmech.fmft_wrapper
-_fmft.argtypes =[p2d, c_int, c_double, c_double, c_int, p2d, c_long]
-_fmft.restype = c_int
-def _check_errors(ret, func, args):
-    if ret<=0:
-        raise RuntimeError("FMFT returned error code %d for the given arguments"%ret)
-    return ret
-_fmft.errcheck = _check_errors
+p2d = np.ctypeslib.ndpointer(dtype = np.float64,ndim = 2,flags = 'C')
+import os
+if not os.getenv('READTHEDOCS'):
+    _fmft = clibcelmech.fmft_wrapper
+    _fmft.argtypes =[p2d, c_int, c_double, c_double, c_int, p2d, c_long]
+    _fmft.restype = c_int
+    def _check_errors(ret, func, args):
+        if ret<=0:
+            raise RuntimeError("FMFT returned error code %d for the given arguments"%ret)
+        return ret
+    _fmft.errcheck = _check_errors
+else:
+    _fmft = lambda *args: None
+
 def _nearest_pow2(x):
 	return int(2**np.floor(np.log2(x)))
 def frequency_modified_fourier_transform(time, z, Nfreq, method_flag = 3, min_freq = None, max_freq = None):
@@ -596,3 +678,135 @@ def truncated_expansion(exprn,order_rules,max_order):
     sexprn = series(exprn.subs(rule),eps,0,max_order+1)
     result = sexprn.removeO().subs({eps:1})
     return result
+
+################################################
+########### Levin Method Integration ###########
+################################################
+
+from scipy.linalg import lu_factor, lu_solve
+def linsolve(A,y):
+    """
+    Solve linear system of equations
+    
+    .. math::
+        A \cdot x = y
+    
+    for y.
+    """
+    return lu_solve(lu_factor(A),y)
+def _chebyshev_gauss_lobatto_points(n,a,b):
+    """Get Gauss-Lobatto quadrature points for Chebyshev polynomials"""
+    return 0.5 * (a+b) + 0.5 * (a-b) * np.cos(np.pi*np.arange(n)/(n-1))
+def _chebyshev_Dmatrix(n):
+    """Chebyshev derivative matrix for pseudo-spectral method"""
+    x = np.cos(np.pi*np.arange(n)/(n-1))
+    c = lambda j: 2 if j==0 or j==n-1 else 1
+    Dkj = lambda k,j: (c(k)/c(j))*(-1)**(k+j+1) / (x[k]-x[j]) if k!=j else 0
+    Dmtrx = np.array([[Dkj(k,j) for j in range(n)]for k in range(n)])
+    Dmtrx -= np.diag(np.sum(Dmtrx,axis=1))
+    return Dmtrx
+def levin_method_integrate(fvec_fn,wvec_fn,Amtrx_fns,a,b,N=32):
+    r"""Evlauate integrals of the form
+
+    .. math::
+        I(a,b) = \int_{a}^{b} \vec{f}(x)\cdot\vec{w}(x) dx
+
+    where the functions :math:`\vec{w}(x)` satisfy a linear differential
+    equation of the form :math:`\frac{d}{dx}\vec{w}(x) = A(x) \cdot
+    \vec{w}(x)`. Evaluation is done using `Levin's method`_.
+
+
+    .. _Levin's method: https://www.sciencedirect.com/science/article/pii/0377042794001189
+
+    Parameters
+    ----------
+    fvec_fn : function
+        A function that returns the vector :math:`\vec{f}(x)`.
+    wvec_fn : function
+        A function that returns the vector :math:`\vec{w}(x)`.
+    Amtrx_fns : list of functions
+        A list of functions giving the entries of matrix :math:`A(x)` appearing
+        in the differential equation obeyed by :math:`\vec{w}(x)`. Input should
+        use nested lists to match the structure of the matrix.
+    a : float
+        Lower integration limit
+    b : float
+        Upper integration limit
+    N : int
+        Number of quadrature points to use
+
+    Returns
+    -------
+    float
+    """
+    chebD = _chebyshev_Dmatrix(N)
+    wa = wvec_fn(a)
+    wb = wvec_fn(b)
+    f = 0.5 * (b-a)
+    xj = _chebyshev_gauss_lobatto_points(N,a,b)
+    zeroN = np.zeros((N,N))
+    M = len(wa)
+    D = np.block([[chebD if j==i else zeroN for j in range(M)] for i in range(M)])    
+    A_tr_mtrx = np.block([[np.diag(Amtrx_fns[i][j](xj)) for i in range(M)] for j in range(M)])
+    Fsoln = linsolve(D + f*A_tr_mtrx,f*np.reshape(fvec_fn(xj),-1))
+    Fa,Fb = Fsoln[::N],Fsoln[N-1::N]
+    ans=Fb@wb - Fa@wa
+    return ans
+def levin_method_integrate_adaptive(fvec_fn,wvec_fn,Amtrx_fns,a,b,N0=32,Nmax=128,rtol = 1.49e-08,atol = 1.49e-08 ):
+    r"""Evlauate integrals of the form
+
+    .. math::
+        I(a,b) = \int_{a}^{b} \vec{f}(x)\cdot\vec{w}(x) dx
+
+    where the functions :math:`\vec{w}(x)` satisfy a linear differential
+    equation of the form :math:`\frac{d}{dx}\vec{w}(x) = A(x) \cdot
+    \vec{w}(x)`. Evaluation is done using `Levin's method`_.
+
+    Method is applied adaptively with increasing number of quadrature points
+    until the estimated error, :math:`\delta` satisfies :math:`\delta <
+    \epsilon_\mathrm{rel}|I(a,b)| + \epsilon_\mathrm{abs}`.
+
+    .. _Levin's method: https://www.sciencedirect.com/science/article/pii/0377042794001189
+
+    Parameters
+    ----------
+    fvec_fn : function
+        A function that returns the vector :math:`\vec{f}(x)`.
+    wvec_fn : function
+        A function that returns the vector :math:`\vec{w}(x)`.
+    Amtrx_fns : list of functions
+        A list of functions giving the entries of matrix :math:`A(x)` appearing
+        in the differential equation obeyed by :math:`\vec{w}(x)`. Input should
+        use nested lists to match the structure of the matrix.
+    a : float
+        Lower integration limit
+    b : float
+        Upper integration limit
+    N0 : int
+        Initial number of Gauss-Lobatto quadrature points to use.
+    Nmax : int
+        Maximum number of quadrature points to use.
+    rtol : float
+        Relative tolerance
+    atol : float
+        Absolute tolerance
+
+    Returns
+    -------
+    float
+    """
+    delta = np.inf
+    ans_old = np.inf
+    N=N0
+    while N<=Nmax:
+        ans = levin_method_integrate(fvec_fn,wvec_fn,Amtrx_fns,a,b,N)
+        delta = np.abs(ans-ans_old)
+        ans_old = ans
+        N*=2
+        if delta < rtol * np.abs(ans) + atol:
+            break
+    else:
+        msg="Exceeded maximum number of quadruature points without converging.\n"
+        msg+="N={}, delta = {}, target = {}".format(N,delta,rtol * np.abs(ans) + atol)
+        warnings.warn(msg)
+    return ans
