@@ -12,8 +12,7 @@ def set_time_step(sim,dtfactor):
     
     Generally, the time step of `WHFAST` should be set to 
     :math:`\lesssim\tau_p/20` in order to obtain reliable
-    results (see :ref:`Wisdom 2015
-    <https://ui.adsabs.harvard.edu/abs/2015AJ....150..127W/abstract>`)
+    results (see `Wisdom 2015 <https://ui.adsabs.harvard.edu/abs/2015AJ....150..127W/abstract>`_)
     """
     ps=sim.particles[1:sim.N_real]
     tperi=np.min([p.P * (1-p.e)**1.5 / np.sqrt(1+p.e) for p in ps])
@@ -33,7 +32,7 @@ def get_simarchive_integration_results(sa,coordinates='jacobi'):
 
     Arguments
     ---------
-    sa : rebound.SimulationArchive or str
+    sa : rebound.Simulationarchive or str
      The simulation archive to read or the file name of the simulation
      archive file. Can also be a reboundx simulation archive.
     coordinates : str
@@ -52,21 +51,21 @@ def get_simarchive_integration_results(sa,coordinates='jacobi'):
         snapshot of the simulation archive.
     """
     if type(sa) == str:
-        sa = rb.SimulationArchive(sa)
+        sa = rb.Simulationarchive(sa)
 
-    if type(sa) == rb.simulationarchive.SimulationArchive:
+    if type(sa) == rb.simulationarchive.Simulationarchive:
         return _get_rebound_simarchive_integration_results(sa,coordinates)
-    elif type(sa) == rbx.simulationarchive.SimulationArchive:
+    elif type(sa) == rbx.simulationarchive.Simulationarchive:
         return _get_reboundx_simarchive_integration_results(sa,coordinates)
     raise TypeError("{} is not a rebound or reboundx simulation archive!".format(sa))
 
 def _get_rebound_simarchive_integration_results(sa,coordinates):
     if coordinates == 'jacobi':
-        get_orbits = lambda sim: sim.calculate_orbits(jacobi_masses=True)
+        get_orbits = lambda sim: sim.orbits(jacobi_masses=True)
     elif coordinates == 'heliocentric':
         get_orbits = get_canonical_heliocentric_orbits
     elif coordinates == 'barycentric':
-        get_orbits = lambda sim: sim.calculate_orbits(sim.calculate_com())
+        get_orbits = lambda sim: sim.orbits(sim.calculate_com())
     else: 
         raise ValueError("'Coordinates must be one of 'jacobi','heliocentric', or 'barycentric'")
     N = len(sa)
@@ -88,7 +87,7 @@ def _get_rebound_simarchive_integration_results(sa,coordinates):
     for i,sim in enumerate(sa):
         sim_results['time'][i] = sim.t
         orbits = get_orbits(sim)
-        sim_results['Energy'][i] = sim.calculate_energy()
+        sim_results['Energy'][i] = sim.energy()
         for j,orbit in enumerate(orbits):
             sim_results['P'][j,i] = orbit.P
             sim_results['e'][j,i] = orbit.e
@@ -102,11 +101,11 @@ def _get_rebound_simarchive_integration_results(sa,coordinates):
 
 def _get_reboundx_simarchive_integration_results(sa,coordinates):
     if coordinates == 'jacobi':
-        get_orbits = lambda sim: sim.calculate_orbits(jacobi_masses=True)
+        get_orbits = lambda sim: sim.orbits(jacobi_masses=True)
     elif coordinates == 'heliocentric':
         get_orbits = get_canonical_heliocentric_orbits
     elif coordinates == 'barycentric':
-        get_orbits = lambda sim: sim.calculate_orbits(sim.calculate_com())
+        get_orbits = lambda sim: sim.orbits(sim.calculate_com())
     else: 
        raise ValueError("'Coordinates must be one of 'jacobi','heliocentric', or 'barycentric'")
     N = len(sa)
@@ -129,7 +128,7 @@ def _get_reboundx_simarchive_integration_results(sa,coordinates):
         sim,extra = sim_extra
         sim_results['time'][i] = sim.t
         orbits = get_orbits(sim)
-        sim_results['Energy'][i] = sim.calculate_energy()
+        sim_results['Energy'][i] = sim.energy()
         for j,orbit in enumerate(orbits):
             sim_results['P'][j,i] = orbit.P
             sim_results['e'][j,i] = orbit.e
@@ -160,9 +159,9 @@ def get_canonical_heliocentric_orbits(sim):
         Orbits of particles in canonical heliocentric
         coordinates.
     """
-    return reb_calculate_orbits(sim, coordinates="canonical heliocentric")
+    return reb_orbits(sim, coordinates="canonical heliocentric")
 
-def reb_calculate_orbits(sim, coordinates="canonical heliocentric"):
+def reb_orbits(sim, coordinates="canonical heliocentric"):
     """
     Compute orbital elements in passed canonical coordinates
 
@@ -227,7 +226,7 @@ def reb_calculate_orbits(sim, coordinates="canonical heliocentric"):
             vy = v_for_orbit[1],
             vz = v_for_orbit[2]
         )
-        orbit = fictitious_particle.calculate_orbit(primary=fictitious_star,G = sim.G)
+        orbit = fictitious_particle.orbit(primary=fictitious_star,G = sim.G)
         orbits.append(orbit)
     return orbits
 
@@ -328,7 +327,7 @@ def reb_add_from_elements(m,elements,sim,coordinates='canonical heliocentric'):
         p.z -= m/Mtot*z
 
 def _compute_transformation_angles(sim):
-    Gtot_vec = sim.calculate_angular_momentum()
+    Gtot_vec = sim.angular_momentum()
     Gtot_vec = np.array(Gtot_vec)
     Gtot = np.sqrt(Gtot_vec @ Gtot_vec)
     Ghat = Gtot_vec / Gtot
@@ -386,7 +385,7 @@ def calculate_mutual_inclinations(s):
 
     Arguments
     ---------
-    s : rebound.Simulation or rebound.SimulationArchive
+    s : rebound.Simulation or rebound.Simulationarchive
 
     Returns
     -------
