@@ -13,7 +13,7 @@ from celmech.disturbing_function import list_secular_terms
 from celmech.disturbing_function import df_coefficient_C, _add_dicts,_consolidate_dictionary_terms
 from celmech.disturbing_function import terms_list_to_HamiltonianCoefficients_dict
 from celmech.disturbing_function import resonant_secular_contribution_dictionary
-from celmech.poisson_series import DFTermSeries
+from celmech.c_poisson_series import DFTermSeries
 
 
 
@@ -21,47 +21,54 @@ class LaplaceLagrangeSystem(Poincare):
     r"""
     A class for representing the classical Laplace-Lagrange secular
     solution for a planetary system.
-    
+
     Attributes
     ----------
     eccentricity_matrix : sympy.Matrix
-      The matrix :math:`\pmb{S}_e` appearing in the secular equations
-      of motion for the eccentricity variables, 
+        The matrix :math:`\pmb{S}_e` appearing in the secular equations of
+        motion for the eccentricity variables,
 
-      .. math::
-            \frac{d}{dt}(\eta_i + i\kappa_i) = [\pmb{S}_e]_{ij} (\eta_j + i\kappa_j)~.
-    
-      or, equivalently,
+        .. math::
+            \frac{d}{dt}(\eta_i + i\kappa_i) = [\pmb{S}_e]_{ij} (\eta_j +
+            i\kappa_j)~.
 
-      .. math::
+        or, equivalently, 
+
+        .. math::
             \frac{d}{dt}\pmb{x} = -i \pmb{S}_e \cdot \pmb{x}
 
-      The matrix is given in symbolic form.
+        The matrix is given in symbolic form.
+
     inclination_matrix : sympy.Matrix
-      The matrix :math:`\pmb{S}_I` appearing in the secular equations
-      of motion for the eccentricity variables, 
+        The matrix :math:`\pmb{S}_I` appearing in the secular equations of
+        motion for the inclination variables, 
 
-      .. math::
-            \frac{d}{dt}(\rho_i + i \sigma_i ) =[\pmb{S}_I]_{ij} (\rho_j + i \sigma_j)~.
-    
-      or, equivalently,
+        .. math::
+            \frac{d}{dt}(\rho_i + i \sigma_i ) = [\pmb{S}_I]_{ij} (\rho_j + i \sigma_j)~.
 
-      .. math::
+        or, equivalently,
+
+        .. math::
             \frac{d}{dt}\pmb{y} = -i \pmb{S}_I \cdot \pmb{y}
 
-      The matrix is given in symbolic form.
+        The matrix is given in symbolic form.
+
     Neccentricity_matrix : ndarray
         Numerical value of the eccentricity matrix :math:`\pmb{S}_e`
+
     Ninclination_matrix : ndarray
         Numerical value of the inclination matrix :math:`\pmb{S}_I`
+
     Tsec : float
         The secular timescale of the system, defined as the shortest
         secular period among the system's inclination and eccentricity
         modes.
+
     eccentricity_eigenvalues : ndarray
-        Array of the eccentricity mode eigenvalues  (i.e., secular frequencies)
+        Array of the eccentricity mode eigenvalues (i.e., secular frequencies)
+
     inclination_eigenvalues : ndarray
-        Array of the inclination mode eigenvalues  (i.e., secular frequencies)
+        Array of the inclination mode eigenvalues (i.e., secular frequencies)
     """
     def __init__(self,G,poincareparticles=[]):
         super(LaplaceLagrangeSystem,self).__init__(G,poincareparticles)
@@ -73,7 +80,7 @@ class LaplaceLagrangeSystem(Poincare):
             self.params.update({m:particle.m,mu:particle.mu,M:particle.M,Lambda:particle.Lambda})
         self.ecc_entries  = {(j,i):S(0) for i in xrange(1,self.N) for j in xrange(1,i+1)}
         self.inc_entries  = {(j,i):S(0) for i in xrange(1,self.N) for j in xrange(1,i+1)}
-        self.tol = np.min([p.m for p in self.particles[1:]]) * np.finfo(np.float).eps
+        self.tol = np.min([p.m for p in self.particles[1:]]) * np.finfo(np.float64).eps
         ps = self.particles[1:]
         self.eta0_vec = np.array([p.eta for p in ps])
         self.kappa0_vec = np.array([p.kappa for p in ps]) 
@@ -132,10 +139,10 @@ class LaplaceLagrangeSystem(Poincare):
             ])
     @property 
     def Neccentricity_matrix(self):
-        return np.array(self.eccentricity_matrix.subs(self.params)).astype(np.float64)
+        return np.array(self.eccentricity_matrix.xreplace(self.params)).astype(np.float64)
     @property 
     def Ninclination_matrix(self):
-        return np.array(self.inclination_matrix.subs(self.params)).astype(np.float64)
+        return np.array(self.inclination_matrix.xreplace(self.params)).astype(np.float64)
     @property
     def Tsec(self):
         Omega_e = np.max( np.abs(self.eccentricity_eigenvalues()) )
@@ -237,26 +244,28 @@ class LaplaceLagrangeSystem(Poincare):
         return {key:val.T for key,val in solution.items()}
     def diagonalize_eccentricity(self):
         r"""
-        Solve for matrix S, that diagonalizes the
-        matrix T in the equations of motion:
+        Solve for matrix :math:`\mathbf{T}_e`, that diagonalizes the matrix
+        :math:`\mathbf{S}_e` in the equations of motion:
 
         .. math::
 
-            \frac{d}{dt}(\eta + i\kappa) = i A \cdot (\eta + i\kappa)
+            \frac{d}{dt}(\eta + \mathrm{i}\kappa) = \mathrm{i} \mathbf{S}_e
+            \cdot (\eta + \mathrm{i}\kappa)
 
-        The matrix S satisfies
+        The matrix :math:`\mathbf{T}_e` satisfies
 
         .. math::
 
-                T^{T} \cdot A \cdot T = D
+                \mathbf{T}_e^{T} \cdot \mathbf{S}_e \cdot \mathbf{T}_e =
+                \mathbf{D}_e
         
-        where D is a diagonal matrix.
-        The equations of motion are decoupled harmonic
-        oscillators in the variables (P,Q) defined by 
+        where D is the diagonal matrix of eccentricity eigenvalues. The secular
+        mode components are given by 
 
         .. math::
 
-            H + i K = S^{T} \cdot (\eta + i \kappa)
+            \mathbf{H} + \mathrm{i} \mathbf{K} = \mathbf{T}_e^{T} \cdot
+            (\pmb{\eta} + \mathrm{i} \pmb{\kappa})
         
         Returns
         -------
@@ -267,27 +276,27 @@ class LaplaceLagrangeSystem(Poincare):
 
     def diagonalize_inclination(self):
         r"""
-        Solve for matrix U, that diagonalizes the
-        matrix B in the equations of motion:
+        Solve for matrix :math:`\mathbf{T}_I`, that diagonalizes the matrix
+        :math:`\mathbf{S}_I` in the equations of motion:
         
         .. math::
-            \frac{d}{dt}(\rho + i\sigma) = i B \cdot (\rho + i\sigma)
+            \frac{d}{dt}(\rho + \mathrm{i}\sigma) = \mathrm{i} \mathbf{S}_I \cdot (\rho + \mathrm{i}\sigma)
 
-        The matrix S satisfies
+        The matrix :math:`\mathbf{T}_I` satisfies
 
         .. math::
-                U^{T} \cdot B \cdot U = D
+                \mathbf{T}_I^{T} \cdot \mathbf{S}_I \cdot \mathbf{T}_I = \mathbf{D}_I
 
-        where D is a diagonal matrix.
-        The equations of motion are decoupled harmonic
-        oscillators in the variables :math:`(R,S)` defined by 
+        where :math:`\mathbf{D}_I` is a diagonal matrix. The equations of motion
+        are decoupled harmonic oscillators in the variables :math:`(R,S)`
+        defined by 
 
         .. math::
-            R + i S = U^{T} \cdot (\rho + i \sigma)
+            R + i S = \mathbf{T}_I^{T}  \cdot (\rho + i \sigma)
         
         Returns
         -------
-        (U , D) : tuple of n x n numpy arrays
+        (T , D) : tuple of n x n numpy arrays
         """
         vals,U = np.linalg.eigh(self.Ninclination_matrix)
         return U, self._chop(np.diag(vals))
@@ -726,79 +735,81 @@ class SecularSplittingIntegrator(RKIntegrator):
 
 class SecularSystemSimulation():
     """
-    A class for integrating the secular equations of motion governing a planetary system.
+    A class for integrating the secular equations of motion governing a
+    planetary system.
 
-    Arguments
-    ---------
+    Parameters
+    ----------
     state : :class:`celmech.poincare.Poincare`
         The initial dynamical state of the system.
 
     dt : float, optional
         The timestep to use for the integration. Either dt or dtFraction must be
         specified.
-
+    
     dtFraction : float, optional
-        Set the timestep to a constant fraction the period of shortest-period linear
-        secular eigenmode.
+        Set the timestep to a constant fraction of the period of the
+        shortest-period linear secular eigenmode.
 
     max_order : int, optional
-        The maximum order of disturbing function terms to include in the integration.
-        By default, the equations of motion include terms up to 4th order.
+        The maximum order of disturbing function terms to include in the
+        integration. By default, the equations of motion include terms up to 4th
+        order.
 
     method : str
-        Integration method to use. Options include:
-            - 'RK' - Direct integration of equations of motion using an Runge-Kutta integration method.
-            - 'splitting' - Applies splitting to the flow generated by the system's Hamiltonian.
+        Integration method to use. Options include - 'RK':  Direct integration
+        of equations of motion using a Runge-Kutta integration method. -
+        'splitting': Applies splitting to the flow generated by the system's
+        Hamiltonian.
 
     resonances_to_include : dict, optional
-        A dictionary containing information that sets the list of MMRs for which the
-        secular contribution will be accounted for (at second order on planet masses).
-        Dictionary key and value pairs are specified in the form
+        A dictionary containing information that sets the list of MMRs for which
+        the secular contribution will be accounted for (at second order on
+        planet masses). Dictionary key and value pairs are specified in the form
 
-              .. code::
+        .. code::
 
-                {(iIn,iOut) : [(j_0,k_0),...(j_N,k_N)]}
-
-        include the resonances :math:`j_i` : :math:`j_i-k_i` with :math:`i=0,...,N` between planets
-        iIn and iOut. Note that harmonics should **NOT** be explicitly included. I.e.,
-        if (2,1) appears in the list [(j_0,k_0),...(j_N,k_N)] then the term (4,2) should
-        **NOT** also appear; these terms' contributions will be added automatically when
-        the (2,1) term is added.
-        By default, no MMRs are included.
+          {(iIn,iOut) : [(j_0,k_0),...,(j_N,k_N)]}
+        
+        This will include the resonances :math:`j_i : j_i-k_i` with
+        :math:`i=0,...,N` between planets iIn and iOut. Note that harmonics
+        should **NOT** be explicitly included. I.e., if (2,1) appears in the
+        list [(j_0,k_0),...(j_N,k_N)] then the term (4,2) should **NOT** also
+        appear; these terms' contributions will be added automatically when the
+        (2,1) term is added. By default, no MMRs are included.
 
     rk_kwargs : dict, optional
-        Keyword arguments that determine details of the Runge-Kutta scheme used to integrate
-        equations of motion. Keywoards include:
-            - :code:`rtol`: float
-                Relative tolerance of root-finding step in the implicit Runge-Kutta scheme.
-                Default is set to machine precision.
-
-            - :code:`atol`: float
-                Absolute tolerance of the root-finding step in the implicit Runge-Kutta scheme.
-                Default is 0 so that tolerance is set solely by :code:`rtol` argument.
+        Keyword arguments that determine details of the Runge-Kutta scheme used
+        to integrate equations of motion. Keywords include
 
+            - :code:`rtol`: float 
+                Relative tolerance of root-finding step in the implicit Runge-Kutta scheme. Default is set to machine precision.
+            - :code:`atol`: float 
+                Absolute tolerance of the root-finding step in the implicit Runge-Kutta scheme. Default is 0 so that tolerance is set solely by :code:`rtol` argument.
             - :code:`rk_method`: str
-                Runge-Kutta method to use.  Available options include:
-                    - 'ImplicitMidpoint'
-                    - 'LobattoIIIB'
-                    - 'GL4'
-                    - 'GL6'
-                    - 'ExplicitMidpoint'
-                    - 'RK4'
+                Runge-Kutta method to use. Available options include:
+
+                    - :code:`'ImplicitMidpoint'`
+                    - :code:`'LobattoIIIB'`
+                    - :code:`'GL4'`
+                    - :code:`'GL6'`
+                    - :code:`'ExplicitMidpoint'`
+                    - :code:`'RK4'`
+
                 'GL4' and 'GL6' are `Gauss-Legendre methods <https://en.wikipedia.org/wiki/Gauss–Legendre_method>`_ of order 4 and 6, respectively.
                 'ImplicitMidpoint', 'GL4', and 'GL6' are symplectic methods while 'LobattoIIIB' is a 4th order time-reversible method (but not symplectic).
                 'ExplicitMidpoint' and 'RK4' are explicit methods that are neither symplectic nor time-reversible.
-
-            - :code:`rk_root_method` : str
+            - :code:`rk_root_method`: str
                 Method to use for root-finding during implicit RK step. Available options are:
-                        - 'Newton'
-                        - 'qausi-Newton'
-                        - 'fixed_point'
-                        - 'explicit'
+
+                    - :code:`'Newton'`
+                    - :code:`'quasi-Newton'`
+                    - :code:`'fixed_point'`
+                    - :code:`'explicit'`
+
                 'Newton' (default) uses Newton's method whereas 'fixed_point' uses a fixed point iteration method.
                 Newton's method requires computing the Jacobian of the equations of motion but has quadratic convergence.
     """
-
     def __init__(self,
                  state,
                  dt=None,dtFraction=None,
@@ -945,79 +956,13 @@ class SecularSystemSimulation():
                        ):
         """
         Initialize a :class:`SecularSystemSimulation <celmech.secular.SecularSystemSimulation>` object
-        from a rebound simulation.
+        from a REBOUND simulation.
 
-        Arguments
-        ---------
+        Parameters
+        ----------
         sim : :class:`rebound.Simulation`
-            REBOUND simulation to convert to :class:`SecularSystemSimulation <celmech.secular.SecularSystemSimulation>`
-
-        dt : float, optional
-            The timestep to use for the integration. Either dt or dtFraction must be
-            specified.
-
-        dtFraction : float, optional
-            Set the timestep to a constant fraction the period of shortest-period linear
-            secular eigenmode.
-
-        max_order : int, optional
-            The maximum order of disturbing function terms to include in the integration.
-            By default, the equations of motion include terms up to 4th order.
-
-        method : str
-            Integration method to use. Options include:
-            - 'RK' - Direct integration of equations of motion using an
-              Runge-Kutta integration method.
-            - 'splitting' - Applies splitting to the flow generated by the
-              system's Hamiltonian.
-
-        resonances_to_include : dict, optional
-            A dictionary containing information that sets the list of MMRs for which the
-            secular contribution will be accounted for (at second order on planet masses).
-            Dictionary key and value pairs are specified in the form
-
-                  .. code::
-
-                    {(iIn,iOut) : [(j_0,k_0),...(j_N,k_N)]}
-
-            include the resonances :math:`j_i` : :math:`j_i-k_i` with :math:`i=0,...,N` between planets
-            iIn and iOut. Note that harmonics should **NOT** be explicitly included. I.e.,
-            if (2,1) appears in the list [(j_0,k_0),...(j_N,k_N)] then the term (4,2) should
-            **NOT** also appear; these terms' contributions will be added automatically when
-            the (2,1) term is added.
-            By default, no MMRs are included.
-
-        rk_kwargs : dict, optional
-            Keyword arguments that determine details of the Runge-Kutta scheme used to integrate
-            equations of motion. Keywoards include:
-                - :code:`rtol`: float
-                    Relative tolerance of root-finding step in the implicit Runge-Kutta scheme.
-                    Default is set to machine precision.
-
-                - :code:`atol`: float
-                    Absolute tolerance of the root-finding step in the implicit Runge-Kutta scheme.
-                    Default is 0 so that tolerance is set solely by :code:`rtol` argument.
-
-                - :code:`rk_method`: str
-                    Runge-Kutta method to use.  Available options include:
-                        - 'ImplicitMidpoint'
-                        - 'LobattoIIIB'
-                        - 'GL4'
-                        - 'GL6'
-                    'GL4' and 'GL6' are `Gauss-Legendre methods <https://en.wikipedia.org/wiki/Gauss–Legendre_method>`_ of order 4 and 6, respectively.
-                    'ImplicitMidpoint', 'GL4', and 'GL6' are symplectic methods while 'LobattoIIIB' is a 4th order time-reversible method (but not symplectic).
-
-                - :code:`rk_root_method` : str
-                    Method to use for root-finding during implicit RK step. Available options are:
-                            - 'Newton'
-                            - 'qausi-Newton'
-                            - 'fixed_point'
-                            - 'explicit'
-                    'Newton' (default) uses Newton's method whereas 'fixed_point' uses a fixed point iteration method.
-                    Newton's method requires computing the Jacobian of the equations of motion but has quadratic convergence.
-    """
-
-
+            REBOUND simulation to convert to :class:`SecularSystemSimulation <celmech.secular.SecularSystemSimulation>`.
+        """
         pvars = Poincare.from_Simulation(sim)
         return cls(pvars,dt,dtFraction,max_order,method,resonances_to_include,rk_kwargs)
 
@@ -1159,8 +1104,10 @@ class SecularSystemSimulation():
 
         .. math::
             \begin{align}
-                D_e &=& T_e^\mathrm{T}S_e T_e\\
-                D_I &=& T_I^\mathrm{T}S_I T_I\\
+                D_e &=& T_e^\mathrm{T}S_e T_e
+                \\
+                D_I &=& T_I^\mathrm{T}S_I T_I
+            \end{align}
 
         that diagonalize the matrices :math:`S_e` 
         and :math:`S_I`.
@@ -1210,7 +1157,7 @@ class SecularSystemSimulation():
             cvars = H.gens
             transformed_vars = np.concatenate((Te.dot(u),TI.dot(v),Te.dot(ubar),TI.dot(vbar)))
             rule={a:b for a,b in zip(cvars,transformed_vars)}
-            H = H.as_expr().subs(rule)
+            H = H.as_expr().xreplace(rule)
             H += De.dot(u).dot(ubar) + DI.dot(v).dot(vbar)
             H = H.as_poly(u+v+ubar+vbar)
         return H
